<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label=" 所选题目选项ID " prop="psqoptionid">
        <el-input
          v-model="queryParams.psqoptionid"
          placeholder="请输入 所选题目选项ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 机构ID " prop="orgid">
        <el-input
          v-model="queryParams.orgid"
          placeholder="请输入 机构ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 机器人选择标记 " prop="isrobot">
        <el-input
          v-model="queryParams.isrobot"
          placeholder="请输入 机器人选择标记 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['smartor:svyfinishoption:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['smartor:svyfinishoption:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['smartor:svyfinishoption:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['smartor:svyfinishoption:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="svyfinishoptionList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 自增ID " align="center" prop="id" />
      <el-table-column label=" 详情ID " align="center" prop="finshresultdetailid" />
      <el-table-column label=" 所选题目选项ID " align="center" prop="psqoptionid" />
      <el-table-column label=" 所填选项内容 " align="center" prop="content" />
      <el-table-column label=" 当前选项得分 " align="center" prop="score" />
      <el-table-column label=" 机构ID " align="center" prop="orgid" />
      <el-table-column label=" 机器人选择标记 " align="center" prop="isrobot" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:svyfinishoption:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:svyfinishoption:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改问卷最终结果选项详情对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label=" 详情ID " prop="finshresultdetailid">
          <el-input v-model="form.finshresultdetailid" placeholder="请输入 详情ID " />
        </el-form-item>
        <el-form-item label=" 所选题目选项ID " prop="psqoptionid">
          <el-input v-model="form.psqoptionid" placeholder="请输入 所选题目选项ID " />
        </el-form-item>
        <el-form-item label=" 所填选项内容 ">
          <editor v-model="form.content" :min-height="192"/>
        </el-form-item>
        <el-form-item label=" 当前选项得分 " prop="score">
          <el-input v-model="form.score" placeholder="请输入 当前选项得分 " />
        </el-form-item>
        <el-form-item label=" 机构ID " prop="orgid">
          <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
        </el-form-item>
        <el-form-item label=" 删除标记 " prop="delFlag">
          <el-select v-model="form.delFlag" placeholder="请选择 删除标记 ">
            <el-option
              v-for="dict in dict.type.sys_yes_no"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label=" 上传标记 " prop="isupload">
          <el-input v-model="form.isupload" placeholder="请输入 上传标记 " />
        </el-form-item>
        <el-form-item label=" 上传时间 " prop="uploadTime">
          <el-date-picker clearable
            v-model="form.uploadTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="请选择 上传时间 ">
          </el-date-picker>
        </el-form-item>
        <el-form-item label=" 是否异常 " prop="isabnormal">
          <el-input v-model="form.isabnormal" placeholder="请输入 是否异常 " />
        </el-form-item>
        <el-form-item label=" 机器人选择标记 " prop="isrobot">
          <el-input v-model="form.isrobot" placeholder="请输入 机器人选择标记 " />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listSvyfinishoption, getSvyfinishoption, delSvyfinishoption, addSvyfinishoption, updateSvyfinishoption } from "@/api/smartor/svyfinishoption";

export default {
  name: "Svyfinishoption",
  dicts: ['sys_yes_no'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 问卷最终结果选项详情表格数据
      svyfinishoptionList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        psqoptionid: null,
        content: null,
        orgid: null,
        isrobot: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "change" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询问卷最终结果选项详情列表 */
    getList() {
      this.loading = true;
      listSvyfinishoption(this.queryParams).then(response => {
        this.svyfinishoptionList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        finshresultdetailid: null,
        psqoptionid: null,
        content: null,
        score: null,
        orgid: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        isabnormal: null,
        isrobot: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加问卷最终结果选项详情";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getSvyfinishoption(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改问卷最终结果选项详情";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateSvyfinishoption(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addSvyfinishoption(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除问卷最终结果选项详情编号为"' + ids + '"的数据项？').then(function() {
        return delSvyfinishoption(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/svyfinishoption/export', {
        ...this.queryParams
      }, `svyfinishoption_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
